==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/wls_multi_datasource.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/vagrant/files/wlst/common.py.erb')
execfile('/vagrant/meta/get_properties.py')

print 'base properties'
properties('/JDBCSystemResources/JDBC Multi Data Source-0','wls_multi_datasource')  # All default properties

print 'JDBCConnectionPoolParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCConnectionPoolParams/JDBC Multi Data Source-0','wls_multi_datasource', 'pool_', 'JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCDriverParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCDriverParams/JDBC Multi Data Source-0','wls_multi_datasource', 'driver_', 'JDBCResource/%{multi_datasource_name}/JDBCDriverParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCOracleParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCOracleParams/JDBC Multi Data Source-0','wls_multi_datasource', 'oracle_', 'JDBCResource/%{multi_datasource_name}/JDBCOracleParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCDataSourceParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCDataSourceParams/JDBC Multi Data Source-0','wls_multi_datasource', 'ds_', 'JDBCResource/%{multi_datasource_name}/JDBCDataSourceParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCXAParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCXAParams/JDBC Multi Data Source-0','wls_multi_datasource', 'xa_', 'JDBCResource/%{multi_datasource_name}/JDBCXAParams/%{multi_datasource_name}/')  # All default properties

print 'InternalProperties'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/InternalProperties/JDBC Multi Data Source-0','wls_multi_datasource', 'internal_', 'JDBCResource/%{multi_datasource_name}/InternalProperties/%{multi_datasource_name}/')  # All default properties

==> enterprisemodules-wls_config-3.4.0.tar.gz: enterprisemodules-wls_config-3.4.0/meta/wls_multi_datasource.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/etc/puppetlabs/code/environments/production/modules/wls_config//lib/puppet/provider/wls_config/wlst/templates/common.py.erb')
execfile('/etc/puppetlabs/code/environments/production/modules/wls_config/meta/get_properties.py')

print 'base properties'
properties('/JDBCSystemResources/JDBC Multi Data Source-0','wls_multi_datasource')  # All default properties

print 'JDBCConnectionPoolParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCConnectionPoolParams/JDBC Multi Data Source-0','wls_multi_datasource', 'pool_', 'JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCDriverParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCDriverParams/JDBC Multi Data Source-0','wls_multi_datasource', 'driver_', 'JDBCResource/%{multi_datasource_name}/JDBCDriverParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCOracleParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCOracleParams/JDBC Multi Data Source-0','wls_multi_datasource', 'oracle_', 'JDBCResource/%{multi_datasource_name}/JDBCOracleParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCDataSourceParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCDataSourceParams/JDBC Multi Data Source-0','wls_multi_datasource', 'ds_', 'JDBCResource/%{multi_datasource_name}/JDBCDataSourceParams/%{multi_datasource_name}/')  # All default properties

print 'JDBCXAParams'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/JDBCXAParams/JDBC Multi Data Source-0','wls_multi_datasource', 'xa_', 'JDBCResource/%{multi_datasource_name}/JDBCXAParams/%{multi_datasource_name}/')  # All default properties

print 'InternalProperties'
properties('/JDBCSystemResources/JDBC Multi Data Source-0/JDBCResource/JDBC Multi Data Source-0/InternalProperties/JDBC Multi Data Source-0','wls_multi_datasource', 'internal_', 'JDBCResource/%{multi_datasource_name}/InternalProperties/%{multi_datasource_name}/')  # All default properties
